@@ -4,6 +4,7 @@ from reprlib import recursive_repr
 
 import abc
 import contextlib
+import collections.abc
 
 abstract = abc.abstractmethod
 recursive = recursive_repr(fillvalue="…")
@@ -46,7 +47,7 @@ class NonSlotted(abc.ABCMeta):
                                                            attributes,
                                                          **kwargs)
 
-class Format(abc.ABC):
+class Format(collections.abc.Callable, metaclass=Slotted):
     
     """ An abstract class representing something that formats something
         else. It only offers the one abstract method, “render(…)” at
@@ -58,6 +59,34 @@ class Format(abc.ABC):
     def render(self, string):
         """ Render a string with respect to the Format instance. """
         ...
+    
+    def __call__(self, string):
+        return self.render(string)
+
+class NonFormat(Format):
+    
+    """ A “format” type whose “render(…)” method is a no-op. """
+    __slots__ = tuple()
+    
+    def __init__(self, *args):
+        pass
+    
+    def render(self, string):
+        """ Return a string, unchanged """
+        return str(string)
+
+class SlottedFormat(Format):
+    
+    """ A base format type, with a slot for a format-operation string. """
+    __slots__ = 'opstring'
+
+class Sanitizer(Format):
+    
+    """ A base format type, with a slot for a compiled regular expression. """
+    __slots__ = 'regex'
+    
+    def render(self, string):
+        return self.regex.sub('', string)
 
 class Cloneable(abc.ABC):
     
@@ -123,10 +152,8 @@ class ReprWrapper(abc.ABC):
     @recursive
     def __repr__(self):
         """ This classes’ object instances’ unique string representation """
-        from clu.repr import typename_hexid
-        cnm, hxa = typename_hexid(self)
-        rpr = self.inner_repr()
-        return f"{cnm}({rpr}) {consts.REPR_DELIMITER} {hxa}"
+        from clu.repr import fullrepr
+        return fullrepr(self, self.inner_repr())
 
 class SlottedRepr(ReprWrapper, metaclass=Slotted):
     
@@ -142,8 +169,8 @@ class SlottedRepr(ReprWrapper, metaclass=Slotted):
         from clu.predicates import slots_for
         from clu.repr import strfields
         return strfields(self,
-               slots_for(self),
-                    try_callables=False)
+               slots_for(type(self)),
+                         try_callables=False)
 
 class MappingViewRepr(ReprWrapper):
     
@@ -155,7 +182,59 @@ class MappingViewRepr(ReprWrapper):
         """ Return the repr string for “self._mapping” """
         return repr(self._mapping)
 
-class Descriptor(SlottedRepr):
+evict_announcer = lambda key, value: print(f"Cache dropped: {key}")
+
+class BaseDescriptor(abc.ABC):
+    
+    __slots__ = tuple()
+    
+    @abstract
+    def __get__(self, instance, cls=None):
+        ...
+
+class DataDescriptor(BaseDescriptor):
+    
+    __slots__ = tuple()
+    
+    @abstract
+    def __set__(self, instance, value):
+        ...
+    
+    def __delete__(self, instance):
+        # raise NotImplementedError("DataDescriptor.__delete__()")
+        pass
+
+class NamedDescriptor(DataDescriptor):
+    
+    __slots__ = tuple()
+    
+    @abstract
+    def __set_name__(self, cls, name):
+        ...
+
+class CacheDescriptor(DataDescriptor, ReprWrapper):
+    
+    __slots__ = ('cache', 'lru')
+    
+    def __init__(self):
+        import zict
+        
+        self.cache = {}
+        self.lru = zict.LRU(18, self.cache,
+                                on_evict=(consts.DEBUG \
+                                      and evict_announcer \
+                                       or None))
+    
+    def __get__(self, *args):
+        return self.lru
+    
+    def __set__(self, instance, value):
+        self.lru = value
+    
+    def inner_repr(self):
+        return repr(self.lru)[1:-1]
+
+class Descriptor(NamedDescriptor, SlottedRepr):
     
     """ A simple, generic desciptor, wrapping one value, and storing its name """
     
@@ -178,7 +257,7 @@ class Descriptor(SlottedRepr):
     def alternative_inner_repr(self):
         from clu.repr import strfield
         value = strfield(self.value)
-        return f"[name={self.name}, value={value}]"
+        return f"name={self.name}, value={value}"
 
 class ValueDescriptor(Descriptor):
     
@@ -188,9 +267,8 @@ class ValueDescriptor(Descriptor):
     
     def __repr__(self):
         """ A custom repr for the ValueDescriptor’s literal value """
-        from clu.constants.consts import ENCODING
         return isinstance(self.value, str)   and self.value or \
-               isinstance(self.value, bytes) and self.value.decode(ENCODING) or \
+               isinstance(self.value, bytes) and self.value.decode(consts.ENCODING) or \
                                             repr(self.value)
 
 class BasePath(Slotted):
@@ -285,11 +363,12 @@ else:
         pass
 
 __all__ = ('Slotted', 'NonSlotted',
-           'Format',
+           'Format', 'NonFormat', 'SlottedFormat', 'Sanitizer',
            'Cloneable',
-           'ReprWrapper',
-           'SlottedRepr', 'MappingViewRepr',
-           'Descriptor', 'ValueDescriptor',
+           'ReprWrapper', 'SlottedRepr', 'MappingViewRepr',
+           'evict_announcer',
+           'BaseDescriptor', 'DataDescriptor', 'NamedDescriptor',
+           'CacheDescriptor', 'Descriptor', 'ValueDescriptor',
            'BasePath', 'AppName',
            'ManagedContext', 'AsyncManagedContext')
 
