@@ -17,9 +17,9 @@ from clu.config.keymapview import NamespaceWalkerKeysView, NamespaceWalkerItemsV
 from clu.config.keymapview import NamespaceWalkerValuesView
 
 from clu.predicates import (isexpandable, iscontainer, isnotnone,
-                            always, uncallable, tuplize)
+                            always, uncallable)
 
-from clu.typology import iterlen
+from clu.typology import iterlen, ismapping
 from clu.exporting import Exporter
 
 exporter = Exporter(path=__file__)
@@ -295,8 +295,8 @@ class NamespaceWalker(FrozenKeyMap):
     
     def flatten(self, cls=None):
         """ Dearticulate an articulated KeyMap instance into one that is flat. """
-        from clu.config.keymap import Flat
         if cls is None:
+            from clu.config.keymap import Flat
             cls = Flat
         out = cls()
         for *namespaces, key, value in self.walk():
@@ -393,7 +393,13 @@ class FlatOrderedSet(collections.abc.Set,
         used to initialize the FlatOrderedSet for which the predicate returns
         a Falsey value. 
     """
-    __slots__ = tuplize('things')
+    __slots__ = ('things', 'predicate')
+    
+    @classmethod
+    def is_a(cls, instance):
+        return isinstance(instance, (cls, FlatOrderedSet)) or \
+               isinstance(getattr(instance, 'things', None),
+                                  collections.abc.Iterable)
     
     def __init__(self, *things, predicate=always):
         """ Initialize a new FlatOrderedSet instance with zero or more things.
@@ -407,11 +413,11 @@ class FlatOrderedSet(collections.abc.Set,
         if len(things) == 1:
             if isexpandable(things[0]):
                 things = things[0]
-            elif iscontainer(things[0]):
+            elif iscontainer(things[0]) and not ismapping(things[0]):
                 things = tuple(things[0])
         for thing in things:
             if thing is not None:
-                if isinstance(thing, type(self)):
+                if type(self).is_a(thing):
                     for other in thing.things:
                         if predicate(other):
                             if other not in thinglist:
@@ -420,6 +426,7 @@ class FlatOrderedSet(collections.abc.Set,
                     if thing not in thinglist:
                         thinglist.append(thing)
         self.things = tuple(thinglist)
+        self.predicate = predicate
     
     def __iter__(self):
         yield from self.things
@@ -434,7 +441,9 @@ class FlatOrderedSet(collections.abc.Set,
         return thing in self.things
     
     def __getitem__(self, idx):
-        return self.things[idx]
+        if isinstance(idx, int):
+            return self.things[idx]
+        return type(self)(*self.things[idx], predicate=self.predicate)
     
     def __bool__(self):
         return len(self.things) > 0
@@ -442,6 +451,20 @@ class FlatOrderedSet(collections.abc.Set,
     def __hash__(self):
         return hash(self.things) & hash(id(self.things))
     
+    def __eq__(self, other):
+        if type(self).is_a(other):
+            return self.things == other.things
+        elif isinstance(other, collections.abc.Sequence):
+            return self.things == tuple(other)
+        return NotImplemented
+    
+    def __ne__(self, other):
+        if type(self).is_a(other):
+            return self.things != other.things
+        elif isinstance(other, collections.abc.Sequence):
+            return self.things != tuple(other)
+        return NotImplemented
+    
     def clone(self, deep=False, memo=None):
         # Q.v. https://stackoverflow.com/a/48550898/298171
         cls = type(self)
@@ -450,11 +473,14 @@ class FlatOrderedSet(collections.abc.Set,
         copier = getattr(copy, deep and 'deepcopy' or 'copy')
         for thing in self.things:
             things.append(copier(thing))
-        super(cls, out).__init__(*things)
+        super(cls, out).__init__(*things, predicate=self.predicate)
         return out
     
     def inner_repr(self):
-        return repr(self.things)
+        # N.B. string-indexing strips off the parens,
+        # which are superfluous as “inner_repr(…)” will
+        # add its own parens by default
+        return repr(self.things)[1:-1]
 
 # CONCRETE CALLABLE SUBTYPES: functional_and, functional_set
 
