@@ -6,14 +6,25 @@ import platform
 import sysconfig
 import sys, os, re
 
-# pytuple shortcut lambda:
+# Choose a “path” interim operator for path-type consts –
+# trying “pathlib.Path”, “pathlib2.Path”, and falling
+# back to string-interning with “sys.intern”:
+try:
+    from clu.constants.polyfills import Path as path
+except (ImportError, SyntaxError):
+    path = sys.intern
+else:
+    if not callable(path):
+        path = sys.intern
+
+# Define the “pytuple” shortcut lambda:
 pytuple = lambda *attrs: tuple(f'__{atx}__' for atx in attrs)
 
 # Appname (née PROJECT_NAME):
 APPNAME = sys.intern('clu')
 
 # Project base path:
-BASEPATH = sys.intern(
+BASEPATH = path(
            os.path.dirname(
            os.path.dirname(
            os.path.dirname(__file__))))
@@ -40,9 +51,6 @@ DEFAULT_TERMINAL_WIDTH = int(os.environ.get('COLUMNS', '100'), base=10)
 # Dollar-sign string (for use in regexing):
 DOLLA = sys.intern('$')
 
-# A prefix to use when creating new modules programmatically:
-DYNAMIC_MODULE_PREFIX = sys.intern('__dynamic_modules__')
-
 # On non-macOS platforms this may be awry:
 ENCODING = sys.intern(sys.getfilesystemencoding().upper()) # 'UTF-8'
 
@@ -57,7 +65,9 @@ FILE_ARGUMENT_NAMES = ('path', 'pth', 'file')
 
 # The hostname for this computer:
 nodename = platform.node().casefold()
-HOSTNAME = sys.intern(f"{nodename}.local")
+HOSTNAME = sys.intern(os.extsep in nodename \
+                               and nodename \
+                             or f"{nodename}.local")
 
 # Determine if we’re running in IPython:
 try:
@@ -105,7 +115,7 @@ PATH = os.getenv("PATH", DEFAULT_PATH)
 PROJECT_NAME = APPNAME
 
 # Path to the projects’ root package directory:
-PROJECT_PATH = sys.intern(os.path.join(BASEPATH, APPNAME))
+PROJECT_PATH = path(os.path.join(BASEPATH, APPNAME))
 
 # Determine if our Python is three’d up:
 PY3 = sys.version_info.major > 2
@@ -134,10 +144,10 @@ SINGLETON_TYPES = (bool, NoneType, EllipsisType, NotImplementedType)
 STRINGPAIR = sys.intern("{!s} : {!s}")
 
 # Path to the script directory:
-SCRIPT_PATH = sys.intern(os.path.join(BASEPATH, APPNAME, 'scripts'))
+SCRIPT_PATH = path(os.path.join(BASEPATH, APPNAME, 'scripts'))
 
 # Path to the project tests:
-TEST_PATH = sys.intern(os.path.join(BASEPATH, 'tests'))
+TEST_PATH = path(os.path.join(BASEPATH, 'tests'))
 
 # Determine if we’re in TextMate:
 TEXTMATE = 'TM_PYTHON' in os.environ
@@ -180,14 +190,6 @@ VERBOTEN += ('Namespace', 'SimpleNamespace')
 # Regex for picking up whitespace:
 WHITESPACE = re.compile(r'\s+')
 
-# XDG_RUNTIME_DIR support:
-basedir = "/usr/local/var/run/xdg"
-symlink = os.path.join(basedir, 'CURRENT')
-
-XDG_RUNTIME_BASE = basedir
-XDG_RUNTIME_DIR = symlink
-XDG_RUNTIME_MODE = 0o700
-
 class NoDefault(object):
     """ A singleton object to signify a lack of an argument. """
     __slots__ = tuple() # type: tuple
@@ -206,9 +208,9 @@ __all__ = ('APPNAME',
            'CPYTHON',
            'DEBUG',
            'DELETE_FLAG',
+           'DEFAULT_PATH',
            'DEFAULT_TERMINAL_WIDTH',
            'DOLLA',
-           'DYNAMIC_MODULE_PREFIX',
            'ENCODING',
            'ENVIRONS_SEP',
            'EXPORTER_NAME',
@@ -216,14 +218,15 @@ __all__ = ('APPNAME',
            'HOSTNAME',
            'IPYTHON',
            'JYTHON',
-           'LAMBDA', 'λ',
+           'LAMBDA',
            'MAXINT',
            'NUMPY',
            'NAMESPACE_SEP',
            'PATH',
-           'PARTIAL', 'φ',
+           'PARTIAL',
            'PROJECT_NAME', 'PROJECT_PATH',
            'PY3', 'PYPY',
+           'PYTHON_BIN',
            'PYTHON_VERSION',
            'QUALIFIER',
            'REPR_DELIMITER',
@@ -236,9 +239,9 @@ __all__ = ('APPNAME',
            'USER',
            'VERBOTEN',
            'WHITESPACE',
-           'XDG_RUNTIME_BASE', 'XDG_RUNTIME_DIR',
-                               'XDG_RUNTIME_MODE',
-           'pytuple', 'NoDefault')
+           'φ', 'λ',
+           'NoDefault',
+           'pytuple')
 
 __dir__ = lambda: list(__all__)
 
@@ -255,10 +258,11 @@ def print_all():
     SEP = ",\n" + (" " * 30)
     
     printout = lambda name, value: print("» %25s : %s" % (name, value))
+    lowers   = lambda string: sum(1 for c in string if c.islower())
     
-    for const_name in __all__:
-        if const_name.endswith('PATH') and os.pathsep in G[const_name]:
-            printout(const_name, G[const_name].replace(os.pathsep, SEP))
+    for const_name in sorted(__all__, key=lowers):
+        if const_name.endswith('PATH') and os.pathsep in str(G[const_name]):
+            printout(const_name, str(G[const_name]).replace(os.pathsep, SEP))
         elif type(G[const_name]) is tuple:
             printout(const_name, SEP.join(f"“{g!s}”" for g in G[const_name]))
         elif type(G[const_name]) is str:
