@@ -16,6 +16,7 @@ import sys, os
 import warnings
 import weakref
 
+abstract = abc.abstractmethod
 chain = itertools.chain
 iterchain = itertools.chain.from_iterable
 
@@ -79,8 +80,8 @@ class Modulespace(object):
     def __getattr__(self, key):
         try:
             module = importlib.import_module(key)
-        except (ModuleNotFoundError, ImportError):
-            raise AttributeError("could not import module: %s" % key)
+        except (ModuleNotFoundError, ImportError) as exc:
+            raise AttributeError("could not import module: %s" % key) from exc
         return module
 
 @cache
@@ -262,6 +263,14 @@ class Registry(abc.ABC, metaclass=clu.abstract.Slotted):
         class keywords already in use.
     """
     
+    @abstract
+    def exports(self):
+        """ An abstract method, ensuring Registry types can’t be just
+            instantiated willy-nilly. The clu.exporting.ExporterBase
+            descendant class implements this method.
+        """
+        ...
+    
     @classmethod
     def __init_subclass__(cls, appname=None, **kwargs):
         if appname:
@@ -558,7 +567,8 @@ class ExporterBase(collections.abc.MutableMapping,
         if thing is self:
             raise ExportError("can’t export an exporter instance directly")
         
-        ### if dname in (λ, φ, name, named):
+        # Re-target bound-method-type things to their parent function definition:
+        target = getattr(thing, '__func__', thing)
         
         # At this point, “named” is valid -- if we were passed
         # a callable, try to rename it with either our valid name,
@@ -571,11 +581,8 @@ class ExporterBase(collections.abc.MutableMapping,
             if named is None:
                 raise ExportError(type(self).messages['noname'] % id(thing))
             
-            # Retrieve the things’ ostensible name attribute value,
+            # Retrieve the things’ ostensible __name__ and __qualname__ attribute values:
             dname = getattr(thing, '__name__')
-            
-            # Re-target bound-method-type things to their parent function definition:
-            target = getattr(thing, '__func__', thing)
             qname = getattr(target, '__qualname__')
             
             # ATTEMPT TO RENAME!!!…
@@ -608,7 +615,6 @@ class ExporterBase(collections.abc.MutableMapping,
         # types that lack mutable __dict__ internals (or at least
         # a settable __doc__ slot or established attribute).
         if doc is not None:
-            target = getattr(thing, '__func__', thing)
             try:
                 target.__doc__ = inspect.cleandoc(doc)
             except (AttributeError, TypeError):
@@ -692,11 +698,15 @@ class ExporterBase(collections.abc.MutableMapping,
         """ Stringify a subset of the Exporter instances’ fields. """
         from clu.repr import strfields
         length = len(self)
-        path = os.path.relpath(self.path, start=self.basepath)
+        if self.path:
+            relpath = os.path.relpath(self.path, start=self.basepath)
+            path = f"“{relpath}”"
+        else:
+            path = "«undefined»"
         return strfields(self, type(self).fields,
                                try_callables=False,
                                items=length,
-                               path=f"“{path}”")
+                               path=f"{path}")
     
     def __enter__(self):
         return self.decorator()
