@@ -6,26 +6,24 @@ from functools import lru_cache, wraps
 cache = lambda function: lru_cache(maxsize=128, typed=True)(function)
 
 import clu.abstract
+import clu.dicts
 import collections
 import collections.abc
 import contextlib
-import os
-import re
 import shutil
-import sys
+import sys, re, os
 import zipfile
 
 from clu.constants.consts import ENCODING, PATH, SCRIPT_PATH
 from clu.constants.exceptions import ExecutionError, FilesystemError
-from clu.dicts import OrderedItemsView, OrderedKeysView, OrderedValuesView
 from clu.predicates import attr, allattrs, isexpandable, anyof
-from clu.repr import stringify, strfields
+from clu.repr import strfields
 from clu.sanitizer import utf8_encode
 from clu.typology import isnotpath, isvalidpath
-from clu.fs.abc import TypeLocker, TemporaryFileWrapper
+from clu.fs.abc import BaseFSName, TemporaryFileWrapper
 from clu.fs.misc import differentfile, filesize, gethomedir, masked_permissions
 from clu.fs.misc import re_matcher, re_searcher, suffix_searcher, re_excluder
-from clu.fs.misc import swapext, u8str, extension
+from clu.fs.misc import swapext, u8str, extension, modeflags, temporary
 from clu.exporting import Exporter, path_to_dotpath
 
 exporter = Exporter(path=__file__)
@@ -203,74 +201,27 @@ def rm_rf(path):
     try:
         if os.path.isfile(path):
             os.unlink(path)
-            return True
+            return not os.path.isfile(path)
         elif os.path.islink(path):
             os.unlink(path)
-            return True
+            return not os.path.islink(path)
         elif os.path.isdir(path):
             shutil.rmtree(path)
-            return True
+            return not os.path.isdir(path)
+        elif os.path.ismount(path):
+            raise FilesystemError(f"Couldn’t rm_rf(…): {path!s} is a mountpoint")
     except FileNotFoundError:
         return False
-    except OSError:
-        return False
-    except IOError as exc:
-        raise FilesystemError(f"Fatal in underlying “rm_rf(…)” syscall: {exc!s}, {path}")
-    raise FilesystemError(f"Couldn’t remove path: {path}")
-
-@export
-def temporary(suffix='', prefix='', parent=None, **kwargs):
-    """ Wrapper around `tempfile.mktemp()` that allows full overriding of the
-        prefix and suffix by the caller -- that is to say, no random elements
-        are used in the returned filename if both a prefix and a suffix are
-        supplied.
-        
-        To avoid problems, the function will throw a FilesystemError if it is
-        called with arguments that result in the computation of a filename
-        that already exists.
-    """
-    from tempfile import mktemp, gettempdir
-    directory = os.fspath(kwargs.pop('dir', parent) or gettempdir())
-    if suffix:
-        if not suffix.startswith(os.extsep):
-            suffix = f"{os.extsep}{suffix}"
-    tempmade = mktemp(prefix=prefix, suffix=suffix, dir=directory)
-    tempsplit = os.path.splitext(os.path.basename(tempmade))
-    if not suffix:
-        suffix = tempsplit[1][1:]
-    if not prefix or kwargs.pop('randomized', False):
-        prefix, _ = os.path.splitext(tempsplit[0]) # WTF, HAX!
-    fullpth = os.path.join(directory, f"{prefix}{suffix}")
-    if os.path.exists(fullpth):
-        raise FilesystemError(f"temporary(): file exists: {fullpth}")
-    return fullpth
-
-@export
-def modeflags(mode, delete=True):
-    """ Convert a file-open modestring to an integer flag.
-        
-        Helper function, used by the “filesystem.TemporaryNamedFile(…)” and
-        “filesystem.NamedTemporaryFile(…)” functions’ internal logic.
-    """
-    from tempfile import _bin_openflags, _text_openflags
-    from clu.constants.consts import DELETE_FLAG
-    
-    if 'b' in u8str(mode):
-        flags = _bin_openflags
-    else:
-        flags = _text_openflags
-    
-    if delete:
-        flags |= DELETE_FLAG
-    
-    return flags
+    except (OSError, IOError) as exc:
+        raise FilesystemError(f"Fatal in underlying “rm_rf(…)” syscall: {path!s}") from exc
+    raise FilesystemError(f"Failed to rm_rf(…): {path!s}")
 
 @cache
 def TemporaryNamedFile(temppath, mode='wb',
                                  delete=True,
                                  buffer_size=-1):
     """ Variation on ``tempfile.NamedTemporaryFile(…)``, for use within
-        `filesystem.TemporaryName()` – q.v. class definition sub.
+        `clu.fs.filesystem.TemporaryName()` – q.v. class definition sub.
         
         Parameters
         ----------
@@ -294,7 +245,7 @@ def TemporaryNamedFile(temppath, mode='wb',
             A ``clu.fs.abc.TemporaryFileWrapper`` object,
             initialized and ready to be used, as per its counterpart(s),
             ``tempfile.NamedTemporaryFile``, and
-            `filesystem.NamedTemporaryFile`.
+            `clu.fs.filesystem.NamedTemporaryFile`.
         
         Raises
         ------
@@ -313,31 +264,29 @@ def TemporaryNamedFile(temppath, mode='wb',
         descriptor = os.open(path, flags)
         filehandle = os.fdopen(descriptor, mode, buffer_size)
         return TemporaryFileWrapper(filehandle, path, delete)
-    except BaseException as base_exception:
+    except BaseException as exc:
         try:
             rm_rf(path)
         finally:
             if descriptor > 0:
                 os.close(descriptor)
-        raise FilesystemError(str(base_exception))
+        raise FilesystemError("error in underlying syscalls") from exc
 
 @export
-class TemporaryName(collections.abc.Hashable,
-                    contextlib.AbstractContextManager,
-                    os.PathLike,
-                    metaclass=TypeLocker):
+class TemporaryName(BaseFSName, contextlib.AbstractContextManager):
     
-    """ This is like NamedTemporaryFile without any of the actual stuff;
-        it just makes a file name -- YOU have to make shit happen with it.
+    """ This is like `NamedTemporaryFile` without any of the actual stuff;
+        it just makes up a file name – YOU have to make shit happen with it.
         But: should you cause such scatalogical events to transpire, this
-        class (when invoked as a context manager) will clean it up for you.
-        Unless you say not to. Really it's your call dogg I could give AF
+        class (when instanced as a context manager) will clean it up for you.
+        Unless you say not to. Really it's your call dogg, I could give AF
     """
     
-    fields = ('name',   'exists', 
-                        'destroy',
-              'mode',   'binary_mode',
-              'prefix', 'suffix', 'dirname')
+    fields = ('name', 'exists', 'destroy',
+              'mode', 'binary_mode',
+             'flags', 'prefix',
+                      'suffix',
+                      'dirname')
     
     def __init__(self, prefix=None, suffix="tmp",
                        parent=None,
@@ -400,27 +349,6 @@ class TemporaryName(collections.abc.Hashable,
         """ The temporary file path (which initially does not exist). """
         return self._name
     
-    @property
-    def basename(self):
-        """ The basename (aka the filename) of the temporary file path. """
-        return os.path.basename(self._name)
-    
-    @property
-    def dirname(self):
-        """ The dirname (aka the enclosing directory) of the temporary file. """
-        return self.parent()
-    
-    @property
-    def exists(self):
-        """ Whether or not there is anything existant at the temporary file path.
-            
-            Note that this property will be true for directories created therein,
-            as well as FIFOs or /dev entries, or any of the other zany filesystem
-            possibilities you and the POSIX standard can imagine, in addition to
-            regular files.
-        """
-        return os.path.exists(self._name)
-    
     @property
     def destroy(self):
         """ Whether or not this TemporaryName instance should destroy any file
@@ -450,8 +378,9 @@ class TemporaryName(collections.abc.Hashable,
             
             Filehandles constructed through “non-binary” TemporaryName instances
             are the other way around – their `write(…)` methods can only be passed
-            instances of `str` (or, `unicode`, for the Python-2 diehards amongst us)
-            or similar; attempt to pass anything `byte`-y and you’ll get raised on.
+            instances of `str` (or, `unicode`, for those Python-2 diehards still
+            remaining amongst us) or similar; attempt to pass anything `byte`-y
+            and you’ll get raised on.
         """
         return 'b' in self._mode
     
@@ -484,11 +413,10 @@ class TemporaryName(collections.abc.Hashable,
         """ The filesize for the temporary file """
         return filesize(self._name)
     
-    def split(self):
-        """ Return (dirname, basename) e.g. for /yo/dogg/i/heard/youlike.jpg,
-            you get back (Directory("/yo/dogg/i/heard"), "youlike.jpg")
-        """
-        return self.dirname, self.basename
+    @property
+    def flags(self):
+        """ A flag value matching the instances’ mode and deletion disposition. """
+        return modeflags(self.mode, self._destroy)
     
     def copy(self, destination):
         """ Copy the file (if one exists) at the instances’ file path
@@ -508,16 +436,6 @@ class TemporaryName(collections.abc.Hashable,
                                 follow_symlinks=True))
         return False
     
-    def parent(self):
-        """ Sugar for `os.path.abspath(os.path.join(self.name, os.pardir))`
-            which, if you are curious, gets you the parent directory of
-            the instances’ target filename, wrapped in a Directory
-            instance.
-        """
-        return self.directory(os.path.abspath(
-                              os.path.join(self.name,
-                                           os.pardir)))
-    
     def read(self, *, original_position=False):
         """ Read data from the temporary name, if it points to an existing file """
         orig, out = 0, b""
@@ -560,65 +478,26 @@ class TemporaryName(collections.abc.Hashable,
     def __enter__(self):
         return self
     
-    def __exit__(self, exc_type=None, exc_val=None, exc_tb=None):
+    def __exit__(self, exc_type=None,
+                       exc_val=None,
+                       exc_tb=None):
         if self.destroy:
             self.close()
         return exc_type is None
     
     def to_string(self):
         """ Stringify the TemporaryName instance. """
-        return stringify(self, type(self).fields, try_callables=False)
-    
-    def __repr__(self):
-        return self.to_string()
-    
-    def __str__(self):
-        if self.exists:
-            return os.path.realpath(self._name)
-        return self._name
-    
-    def __bytes__(self):
-        return bytes(str(self), encoding=ENCODING)
-    
-    def __fspath__(self):
-        return self._name
-    
-    def __bool__(self):
-        return self.exists
-    
-    def __eq__(self, other):
-        if isnotpath(other):
-            return NotImplemented
-        try:
-            return os.path.samefile(self._name,
-                                    os.fspath(other))
-        except FileNotFoundError:
-            return False
-    
-    def __ne__(self, other):
-        if isnotpath(other):
-            return NotImplemented
-        try:
-            return differentfile(self._name,
-                                 os.fspath(other))
-        except FileNotFoundError:
-            return True
-    
-    def __hash__(self):
-        return hash((self._name, self.exists))
+        return strfields(self, type(self).fields, try_callables=False)
 
 non_dotfile_matcher = re_matcher(r"^[^\.]")
 
 @export
-class Directory(collections.abc.Hashable,
+class Directory(BaseFSName,
                 collections.abc.Reversible,
                 collections.abc.Mapping,
                 collections.abc.Sized,
                 clu.abstract.Cloneable,
-                clu.abstract.ReprWrapper,
-                contextlib.AbstractContextManager,
-                os.PathLike,
-                metaclass=TypeLocker):
+                contextlib.AbstractContextManager):
     
     """ A context-managed directory: change in on enter, change back out
         on exit. Plus a few convenience functions for listing and whatnot.
@@ -662,20 +541,6 @@ class Directory(collections.abc.Hashable,
         """ The instances’ target directory path. """
         return attr(self, 'target', 'new')
     
-    @property
-    def basename(self):
-        """ The basename (aka the name of the directory, like as opposed to the
-            entire fucking absolute path) of the target directory.
-        """
-        return os.path.basename(self.name)
-    
-    @property
-    def dirname(self):
-        """ The dirname (aka the path of the enclosing directory) of the target
-            directory, wrapped in a new Directory instance.
-        """
-        return self.parent()
-    
     @property
     def exists(self):
         """ Whether or not the instances’ target path exists as a directory. """
@@ -707,13 +572,6 @@ class Directory(collections.abc.Hashable,
                               'did_change',
                               'did_change_back')
     
-    def split(self):
-        """ Return a two-tuple containing `(dirname, basename)` – like e.g.
-            for `/yo/dogg/i/heard/youlike`, your return value will be like
-            `(Directory("/yo/dogg/i/heard"), "youlike")`
-        """
-        return self.dirname, self.basename
-    
     def ctx_initialize(self):
         """ Restores the instance to the freshly-allocated state -- with one
             notable exception: if it had been previously prepared (through a
@@ -819,12 +677,6 @@ class Directory(collections.abc.Hashable,
         self.ctx_initialize()
         return False
     
-    def realpath(self, source=None):
-        """ Sugar for calling os.path.realpath(self.name) """
-        return u8str(
-            os.path.realpath(
-            os.fspath(source or self.name)))
-    
     def ls(self, suffix=None, source=None):
         """ List files -- defaults to the process’ current working directory.
             As per the UNIX custom, files whose name begins with a dot are
@@ -891,8 +743,8 @@ class Directory(collections.abc.Hashable,
                         os.fspath(subpath or os.curdir))),
                         exist_ok=False,
                         mode=masked_permissions(mode))
-        except OSError as os_error:
-            raise FilesystemError(str(os_error))
+        except OSError as exc:
+            raise FilesystemError("error in underlying syscalls") from exc
         return self
     
     def walk(self, followlinks=True):
@@ -903,37 +755,6 @@ class Directory(collections.abc.Hashable,
         """
         return os.walk(self.name, followlinks=followlinks)
     
-    def parent(self):
-        """ Sugar for `os.path.abspath(os.path.join(self.name, os.pardir))`
-            which, if you are curious, gets you the parent directory of
-            the instances’ target directory, wrapped in a Directory
-            instance.
-        """
-        return self.directory(os.path.abspath(
-                              os.path.join(self.name,
-                                           os.pardir)))
-    
-    def relparent(self, path):
-        """ Relativize a path, relative to the parent of the directory,
-            and return it as a string.
-            
-            Used internally in the implementations of the instance
-            methods “Directory.flatten(…)”, and “Directory.zip_archive(…)”.
-        """
-        return os.path.relpath(path, start=os.path.abspath(
-                                           os.path.join(self.name,
-                                                        os.pardir)))
-    
-    def relprefix(self, path, separator='_'):
-        """ Return a “prefix” string based on a file path –
-            the actual path separators are replaced with underscores,
-            with which the individual path segments are joined, creating
-            a single long string that is unique to the original file path.
-            
-            Used internally in the implementation of “Directory.flatten(…)”.
-        """
-        return (self.relparent(path) + os.sep).replace(os.sep, separator)
-    
     def flatten(self, destination, suffix=None, new_suffix=None):
         """ Copy the entire directory tree, all contents included, to a new
             destination path – with all files residing within the same directory
@@ -1062,21 +883,6 @@ class Directory(collections.abc.Hashable,
             assert ztmp.copy(zpth)
         return self.realpath(zpth)
     
-    def symlink(self, destination, source=None):
-        """ Create a symlink at `destination`, pointing to this instances’
-            directory path (or an alternative source path, if specified).
-            
-            The `destination` argument can be anything path-like: instances of
-            `str`, `unicode`, `bytes`, `bytearray`, `pathlib.Path`, `os.PathLike`,
-            or anything with an `__fspath__(…)` method. 
-        """
-        if destination is None:
-            raise FilesystemError("“symlink(…)” destination path cannot be None")
-        os.symlink(os.fspath(source or self.name),
-                   os.fspath(destination),
-                   target_is_directory=True)
-        return self
-    
     def importables(self, subdir, suffix='py',
                                   source=None,
                                   excludes=('-', '+', 'pytest',
@@ -1106,7 +912,7 @@ class Directory(collections.abc.Hashable,
                                excludes=('~', '#', 'ds_store', '.git')):
         """ Return a ‘collections.Counter’ filled with a histogram of the
             file suffixes for all files found in the given subdirectory,
-            excluding anything matching any of the “excludes” strings
+            excluding anything matching any of the “excludes” strings.
         """
         excluder = re_excluder(excludes)
         searcher = re_searcher(re.escape(os.extsep))
@@ -1127,53 +933,31 @@ class Directory(collections.abc.Hashable,
                        excludes=('~', '#', 'ds_store', '.git')):
         """ Return a generator over all the file suffixes of all files
             found recursively within the given subdirectory, excluding
-            anything matching any of the “excludes” strings
+            anything matching any of the “excludes” strings.
         """
         yield from self.suffix_histogram(subdir=subdir,
                                          source=source,
                                        excludes=excludes).keys()
     
-    def close(self):
-        """ Stub method -- always returns True: """
-        return True
-    
     def to_string(self):
         """ Stringify the Directory instance. """
-        return strfields(self, type(self).fields)
-    
-    def inner_repr(self):
-        """ Stringify the Directory instance. """
-        return self.to_string()
+        return strfields(self, type(self).fields, try_callables=False)
     
     @wraps(dict.items)
     def items(self):
-        return OrderedItemsView(self)
+        return clu.dicts.OrderedItemsView(self)
     
     @wraps(dict.keys)
     def keys(self):
-        return OrderedKeysView(self)
+        return clu.dicts.OrderedKeysView(self)
     
     @wraps(dict.values)
     def values(self):
-        return OrderedValuesView(self)
+        return clu.dicts.OrderedValuesView(self)
     
     def clone(self, deep=False, memo=None):
         return self.directory(self.name)
     
-    def __str__(self):
-        if self.exists:
-            return self.realpath()
-        return self.name
-    
-    def __bytes__(self):
-        return bytes(str(self), encoding=ENCODING)
-    
-    def __fspath__(self):
-        return self.name
-    
-    def __bool__(self):
-        return self.exists
-    
     def __iter__(self):
         if self.exists:
             with os.scandir(os.path.realpath(self.name)) as iterscan:
@@ -1209,27 +993,6 @@ class Directory(collections.abc.Hashable,
     
     def __rtruediv__(self, filepath):
         return self.directory(filepath).subdirectory(self)
-    
-    def __eq__(self, other):
-        if isnotpath(other):
-            return NotImplemented
-        try:
-            return os.path.samefile(self.name,
-                                    os.fspath(other))
-        except FileNotFoundError:
-            return False
-    
-    def __ne__(self, other):
-        if isnotpath(other):
-            return NotImplemented
-        try:
-            return differentfile(self.name,
-                                 os.fspath(other))
-        except FileNotFoundError:
-            return True
-    
-    def __hash__(self):
-        return hash((self.name, self.exists))
 
 @export
 class cd(Directory):
@@ -1275,9 +1038,12 @@ class TemporaryDirectory(Directory):
     """
     
     fields = ('name', 'old', 'new', 'exists',
-              'destroy', 'prefix',  'suffix', 'parent',
-              'will_change',        'did_change',
-              'will_change_back',   'did_change_back')
+              'destroy', 'prefix', 
+                         'suffix',
+                         'parent',
+                   'change',
+              'will_change',      'did_change',
+              'will_change_back', 'did_change_back')
     
     def __init__(self, prefix="TemporaryDirectory-", suffix="",
                                                      parent=None,
@@ -1424,11 +1190,11 @@ def NamedTemporaryFile(mode='w+b', buffer_size=-1,
     try:
         filehandle = os.fdopen(descriptor, mode, buffer_size)
         return TemporaryFileWrapper(filehandle, name, delete)
-    except BaseException as base_exception:
+    except BaseException as exc:
         rm_rf(name)
         if descriptor > 0:
             os.close(descriptor)
-        raise FilesystemError(str(base_exception))
+        raise FilesystemError("error in underlying syscalls") from exc
 
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
 __all__, __dir__ = exporter.all_and_dir()
\ No newline at end of file
