@@ -5,19 +5,19 @@ from collections import namedtuple as NamedTuple
 import abc
 import colorama
 import clu.abstract
+import collections.abc
 import inspect
 import textwrap
-import sys
-import zict
+import sys, re
 
 abstract = abc.abstractmethod
 
-from clu.constants.consts import DEBUG, ENCODING, SEPARATOR_WIDTH
+from clu.constants.consts import ENCODING, SEPARATOR_WIDTH
 from clu.constants.polyfills import Enum, unique, auto
 from clu.predicates import mro, or_none
 from clu.typology import dict_types, isstring, isbytes
 from clu.fs.misc import re_matcher
-from clu.naming import nameof, qualified_name
+from clu.naming import nameof, qualified_name, isinspectable
 from clu.enums import alias, AliasingEnumMeta
 from clu.stdio import std, linebreak, flush_all
 from clu.exporting import Exporter
@@ -28,7 +28,6 @@ export = exporter.decorator()
 # colorama.init()
 
 print_separator = lambda filler='-': print(filler * SEPARATOR_WIDTH)
-evict_announcer = lambda key, value: print(f"Cache dropped: {key}")
 
 @export
 class ANSIBase(Enum):
@@ -39,26 +38,6 @@ class ANSIBase(Enum):
     def is_ansi(cls, instance):
         return cls in mro(instance)
 
-class CacheDescriptor(object):
-    
-    __slots__ = ('cache', 'lru')
-    
-    def __init__(self):
-        self.cache = {}
-        self.lru = zict.LRU(18, self.cache,
-                                on_evict=(DEBUG \
-                                      and evict_announcer \
-                                       or None))
-    
-    def __get__(self, *args):
-        return self.lru
-    
-    def __set__(self, instance, value):
-        self.lru = value
-    
-    def __repr__(self):
-        return repr(self.lru)
-
 @export
 class ANSI(AliasingEnumMeta):
     
@@ -78,14 +57,15 @@ class ANSI(AliasingEnumMeta):
         """
         source = kwargs.pop('source')
         
-        class SourceDescriptor(object):
+        class SourceDescriptor(clu.abstract.BaseDescriptor,
+                               clu.abstract.ReprWrapper):
             
             __slots__ = tuple()
             
             def __get__(self, *args):
                 return source
             
-            def __repr__(self):
+            def inner_repr(self):
                 return repr(source)
         
         def init_method(self, value):
@@ -111,7 +91,7 @@ class ANSI(AliasingEnumMeta):
         def to_string(self):
             return str(self.code)
         
-        attributes['cache']     = CacheDescriptor()
+        attributes['cache']     = clu.abstract.CacheDescriptor()
         attributes['source']    = SourceDescriptor()
         attributes['__init__']  = init_method
         attributes['__bool__']  = bool_method
@@ -252,6 +232,7 @@ ANSIFormatBase = NamedTuple('ANSIFormatBase', FIELDS)
 class ANSIFormat(clu.abstract.Format,
                  clu.abstract.Cloneable,
                  clu.abstract.ReprWrapper,
+                 collections.abc.Hashable,
                  ANSIFormatBase):
     
     """ The formatter class for ANSI markup codes. """
@@ -401,38 +382,57 @@ class ANSIFormat(clu.abstract.Format,
         return f"{prefix}{string!s}{suffix}"
 
 @export
-class NonFormat(clu.abstract.Format):
-    
-    """ A “format” type whose “render(…)” method is a no-op. """
+class ANSISanitizer(clu.abstract.Sanitizer):
     
     def __init__(self, *args):
-        pass
-    
-    def render(self, string):
-        """ Return a string, unchanged """
-        return string
+        """ Initialize with ANSI code sanitizer regex.
+            
+            Any arguments passed will be unceremoniously swallowed.
+        """
+        # q.v. https://stackoverflow.com/a/14693789/298171 for the regex
+        self.regex = re.compile(
+                     r'\x1B(?:[@-Z\\-_]|\[[0-?]*[ -/]*[@-~])')
 
 @export
-def print_ansi(text, color=None, file=std.OUT):
+def print_ansi(text, **kwargs):
     """ print_ansi(…) → Print text in ANSI color, using optional inline markup
                         from `colorama` for terminal color-escape delimiters """
-    FormatClass = file.isatty() and ANSIFormat or NonFormat
-    fmt = FormatClass(color)
+    color   = kwargs.pop('color',   None)
+    file    = kwargs.pop('file', std.OUT)
+    sep     = kwargs.pop('sep',   """""")
+    end     = kwargs.pop('end',     '\n')
+    fmt     = kwargs.pop('fmt',     None)
+    
+    # FormatClass = file.isatty() and ANSIFormat or clu.abstract.NonFormat
+    if not fmt:
+        FormatClass = kwargs.pop('FormatClass', file.isatty() \
+                                                and ANSIFormat \
+                                                 or ANSISanitizer)
+        fmt = FormatClass(color)
+    
     for line in text.splitlines():
-        print(fmt.render(line), sep='', end='\n', file=file)
+        out = fmt.render(line)
+        print(out, sep=sep,
+                   end=end,
+                  file=file)
     return None
 
 @export
-def print_ansi_centered(text=None, color=None,
-                                   filler='•',
+def print_ansi_centered(text=None, filler='•',
                                    width=None,
-                                   file=std.OUT):
+                                   color=None,
+                                   file=std.OUT,
+                                 **kwargs):
     """ print_ansi_centered(…) → Print a string to the terminal, centered
                                  and bookended with asterisks """
     if text is None:
-        return print_ansi(filler * (width or SEPARATOR_WIDTH), color=color, file=file)
+        return print_ansi(filler * (width or SEPARATOR_WIDTH), color=color,
+                                                                file=file,
+                                                                   **kwargs)
     message = f" {text.strip()} "
-    return print_ansi(message.center(width or SEPARATOR_WIDTH, filler), color=color, file=file)
+    return print_ansi(message.center(width or SEPARATOR_WIDTH, filler), color=color,
+                                                                         file=file,
+                                                                            **kwargs)
 
 LIGHTBLUE   = ANSIFormat(text=Text.LIGHTBLUE)
 DARKGRAY    = ANSIFormat(text=Text.GRAY)
@@ -440,24 +440,31 @@ RED         = ANSIFormat(text=Text.RED)
 NOTHING     = ANSIFormat()
 
 chevron     = RED.render("»")
+chevrons    = RED.render(">>>")
 colon       = DARKGRAY.render(":")
 
 @export
 def print_ansi_name_value(name, value, most=25,
                                     pilcrow=chevron,
                                      equals=colon,
+                                      color=NOTHING,
+                                       file=std.OUT,
                                   namecolor=LIGHTBLUE,
                                  valuecolor=DARKGRAY,
-                                       file=std.OUT):
+                                   **kwargs):
     """ Format and colorize each segment of the name/value output """
+    
     key = namecolor.render(f" {name} ".rjust(most+2))
     val = valuecolor.render(f" {value!s}")
     return print_ansi(pilcrow + key
-                     + equals + val, color=NOTHING)
+                     + equals + val, color=color,
+                                      file=file,
+                                         **kwargs)
 
 # Regex boolean predicates for matching marked (or bulleted) paragraphs:
-para_mark_matcher = re_matcher(r"^\s*[0-9+•⌀\<\>«»→\#¬†‡¶§±–\-\+\*]+")
-para_line_matcher = re_matcher(r"^\s*[+•⌀\<\>«»→\#¬†‡¶§±–\-\+\*]+")
+para_mark_matcher = re_matcher(r"^\s*[0-9•⌀\<\>«»→\#¬†‡¶§±–\-\+\*]+")
+para_line_matcher = re_matcher(r"^\s*[•⌀\<\>«»→\#¬†‡¶§±–\-\+\*]+")
+para_code_matcher = re_matcher(r"^\s*\>{3,5}")
 
 @export
 def paragraphize(doc):
@@ -473,8 +480,28 @@ def paragraphize(doc):
                 lines[idx] += " "
     return ''.join(lines).splitlines()
 
+# Regex to insert a comment mark prior to an “arrow” glyph,
+# and to update said glyph to a nicely higher codepoint:
+arrow_re = re.compile(r'[\-–—]+>')
+arrow_sb = '# →'
+
 @export
-def highlight(code_string, language='json',
+def signature(thing):
+    """ Retrieve the signature for a thing, parsing the docstring
+        if necessary.
+    """
+    try:
+        return nameof(thing) + str(inspect.signature(thing))
+    except ValueError as exc:
+        if 'no signature found' in str(exc):
+            doc = inspect.getdoc(thing)
+            if doc:
+                return arrow_re.sub(arrow_sb,
+                                    doc.splitlines()[0].strip())
+    return None
+
+@export
+def highlight(code_string, language='python',
                              markup='terminal256',
                               style='paraiso-dark',
                              isatty=True):
@@ -488,6 +515,53 @@ def highlight(code_string, language='json',
     formatter = pygments.formatters.get_formatter_by_name(markup, style=style)
     return pygments.highlight(code_string, lexer=LexerCls(), formatter=formatter)
 
+@export
+class ANSICodeHighlighter(clu.abstract.SlottedFormat):
+    
+    __slots__ = ('markup', 'style')
+    
+    def __init__(self, language='python',
+                         markup='terminal256',
+                          style='paraiso-dark'):
+        self.opstring = language
+        self.markup = markup
+        self.style = style
+    
+    def render(self, string):
+        return highlight(string, language=self.opstring,
+                                   markup=self.markup,
+                                    style=self.style)
+
+@export
+class PygmentsHighlighter(clu.abstract.Format):
+    
+    __slots__ = ('lexer', 'formatter')
+    
+    def __init__(self, language='python',
+                         markup='terminal256',
+                          style='paraiso-dark'):
+        from pygments.lexers import find_lexer_class_by_name as get_lexer_class
+        from pygments.formatters import get_formatter_by_name as get_formatter
+        self.lexer = get_lexer_class(language)()
+        self.formatter = get_formatter(markup, style=style)
+    
+    def render(self, string):
+        from pygments import highlight as pygmenticate
+        return pygmenticate(string, lexer=self.lexer,
+                                formatter=self.formatter)
+
+@export
+class TextWrapper(clu.abstract.Format):
+    
+    __slots__ = ('kwargs', 'textwrapper')
+    
+    def __init__(self, **kwargs):
+        self.kwargs = kwargs
+        self.textwrapper = textwrap.TextWrapper(**kwargs)
+    
+    def render(self, string):
+        return self.textwrapper.fill(string)
+
 # Margin-dwelling legibility symbols:
 INITIAL         = '  ¶ '
 SUBSEQUENT      = '    '
@@ -495,6 +569,145 @@ SUBSEQUENT      = '    '
 # Pre-calculate eighty-percent width:
 EIGHTY_PERCENT  = int(SEPARATOR_WIDTH * 0.8)
 
+BASE_KWARGS = dict(initial_indent=INITIAL,
+                   subsequent_indent=SUBSEQUENT,
+                   break_on_hyphens=False,
+                   drop_whitespace=True,
+                   replace_whitespace=True,
+                   placeholder="…",
+                   tabsize=4,
+                   width=EIGHTY_PERCENT)
+
+wrapper_kws = lambda **kwargs: { **BASE_KWARGS, **kwargs }
+
+@export
+class HighlighterWrapper(TextWrapper):
+    
+    def __init__(self):
+        super().__init__(**wrapper_kws())
+
+@export
+class DualOptionWrapper(clu.abstract.Format):
+    
+    __slots__ = ('kwargs', 'wrap', 'kwalts', 'warp')
+    
+    def __init__(self, kwargs, kwalts):
+        self.kwargs = kwargs
+        self.kwalts = kwalts
+        self.wrap = textwrap.TextWrapper(**kwargs)
+        self.warp = textwrap.TextWrapper(**kwalts)
+
+@export
+class ParagraphWrapper(DualOptionWrapper):
+    
+    def __init__(self):
+        # N.B. kwargs → marked, kwalts → unmarked
+        super().__init__(kwargs=wrapper_kws(initial_indent=SUBSEQUENT),
+                         kwalts=wrapper_kws(replace_whitespace=False))
+    
+    def code_mark(self, string):
+        return para_code_matcher(string) \
+              and chevrons + " " \
+               or self.wrap.fill(string)
+    
+    def render(self, string):
+        return para_mark_matcher(string) \
+              and self.wrap.fill(string) \
+               or self.warp.fill(string)
+
+@export
+class StagedFormat(clu.abstract.Format):
+    
+    __slots__ = 'formatters'
+    
+    def __init__(self, *args):
+        self.formatters = args
+    
+    def render(self, string):
+        for formatter in self.formatters:
+            string = formatter.render(string)
+        return string
+
+@export
+class DocFormat(clu.abstract.Format):
+    
+    head = ANSIFormat(text=Text.CYAN)
+    body = ANSIFormat(text=Text.GRAY)
+    wrap = ParagraphWrapper()
+    
+    code = StagedFormat(HighlighterWrapper(),
+                        PygmentsHighlighter())
+    para = StagedFormat(wrap, body)
+    null = StagedFormat(wrap, ANSISanitizer())
+    
+    __slots__ = 'iohandle'
+    
+    def __init__(self, iohandle=std.OUT):
+        self.iohandle = iohandle
+    
+    @property
+    def isatty(self):
+        return bool(self.iohandle.isatty())
+    
+    def get(self, atx):
+        cls = type(self)
+        if not self.isatty:
+            return cls.null
+        if not hasattr(cls, atx):
+            raise AttributeError(f"format not found: {atx!s}")
+        return getattr(cls, atx)
+    
+    def put(self, string):
+        return print(string, file=self.iohandle)
+    
+    def putcenter(self, text=None, filler='•', width=None, color=None, **kwargs):
+        file = kwargs.get('file', self.iohandle)
+        return print_ansi_centered(text=text, filler=filler,
+                                               width=width,
+                                               color=color,
+                                                file=file,
+                                                   **kwargs)
+    
+    def putln(self, count=1):
+        for idx in range(count):
+            print(file=self.iohandle)
+    
+    def putcode(self, codestring):
+        return self.put(
+               self.get('code').render(codestring))
+    
+    def putpara(self, paragraph):
+        if paragraph:
+            return self.put(
+                   self.get('para').render(paragraph))
+        return self.putln()
+    
+    def render(self, thing):
+        # cls = type(self)
+        thingname = nameof(thing)
+        doc = inspect.getdoc(thing) or "«¡no docstring found!»"
+        sig = signature(thing) or ""
+        paras = paragraphize(doc)
+        self.putln()
+        
+        self.putcenter(f"__doc__ for “{thingname}”",
+                       color=self.get('head'))
+        self.putln()
+        
+        if sig:
+            self.putcode(sig)
+            self.putln(count=int(not self.isatty))
+        
+        start = int(not isinspectable(thing)) * 2
+        for paragraph in paras[start:]:
+            self.putpara(paragraph)
+    
+    def __call__(self, *things):
+        for thing in things:
+            self.render(thing)
+        
+        self.putln(count=2)
+
 @export
 def ansidoc(*things):
     """ ansidoc(*things) → Print the docstring value for each thing, in ANSI color """
@@ -506,38 +719,34 @@ def ansidoc(*things):
         # Process each things’ name and doc
         thingname = nameof(thing)
         doc = inspect.getdoc(thing) or "«¡no docstring found!»"
-        sig = inspect.signature(thing) or ""
+        sig = signature(thing) or ""
         paras = paragraphize(doc)
         
-        # Print the ANSI header
-        print_ansi_centered(f"__doc__ for “{thingname}”", color=Text.CYAN)
-        linebreak()
+        print_ansi_centered(f"__doc__ for “{thingname}”",
+                            color=Text.CYAN)
+        flush_all()
+        print()
         
         # Code-highlight, format and print the thing and its call-signature:
-        print(highlight(textwrap.fill(f"{thingname}{sig}",
-                        initial_indent=INITIAL,
-                        subsequent_indent=SUBSEQUENT,
-                        replace_whitespace=True,
-                        placeholder="…",
-                        tabsize=4,
-                        width=EIGHTY_PERCENT), language='python',
-                                               isatty=std.OUT.isatty()),
-                                               sep='', end='\n',
-                                               file=std.OUT)
+        if sig:
+            print(highlight(textwrap.fill(sig, **wrapper_kws()),
+                            isatty=std.OUT.isatty()),
+                            sep='', end='\n',
+                            file=std.OUT)
+            
+            if not std.OUT.isatty():
+                flush_all()
+                print()
         
         # Format and print each paragraph
-        for para in paras:
+        start = int(not isinspectable(thing)) * 2
+        for para in paras[start:]:
             if para:
                 marked = para_mark_matcher(para)
-                print_ansi(textwrap.fill(para, initial_indent=marked and SUBSEQUENT or INITIAL,
-                                            subsequent_indent=SUBSEQUENT,
-                                           replace_whitespace=marked,
-                                             break_on_hyphens=False,
-                                              drop_whitespace=True,
-                                                  placeholder='…',
-                                                      tabsize=4,
-                                                        width=EIGHTY_PERCENT),
-                                                        color=Text.GRAY)
+                print_ansi(textwrap.fill(para,
+                           **wrapper_kws(initial_indent=marked and SUBSEQUENT or INITIAL,
+                                         replace_whitespace=marked)),
+                                         color=Text.GRAY)
             else:
                 linebreak()
         
@@ -547,7 +756,11 @@ def ansidoc(*things):
         flush_all()
 
 export(print_separator,     name='print_separator', doc="print_separator(filler='-') → print ‘filler’ character consts.SEPARATOR_WIDTH times")
-export(evict_announcer,     name='evict_announcer', doc="evict_announcer(key, value) → print a debug trace message about the key and value")
+export(wrapper_kws,         name='wrapper_kws',     doc="wrapper_kws(**kwargs) → prepare default arguments for instancing a “textwrap.TextWrapper”")
+export(ANSIFormatBase,      name='ANSIFormatBase')
+
+export(SEPARATOR_WIDTH,     name='SEPARATOR_WIDTH')
+export(EIGHTY_PERCENT,      name='EIGHTY_PERCENT')
 
 # NO DOCS ALLOWED:
 export(Text)
@@ -561,6 +774,7 @@ __all__, __dir__ = exporter.all_and_dir()
 def test():
     
     from clu.testing.utils import inline
+    from itertools import product
     
     @inline
     def test_one():
@@ -569,9 +783,18 @@ def test():
     
     @inline
     def test_two():
-        ansidoc(ansidoc)
+        # ansidoc(Enum)
+        # ansidoc(ansidoc)
+        ansidoc(Exporter)
+        ansidoc(product)
     
-    return inline.test(10)
+    @inline
+    def test_three():
+        fmt = DocFormat()
+        fmt(Exporter)
+        fmt(product)
+    
+    return inline.test()
 
 if __name__ == '__main__':
     sys.exit(test())
\ No newline at end of file
