@@ -6,14 +6,16 @@ from functools import lru_cache
 import collections.abc
 import clu.abstract
 import clu.dicts
+import clu.all
 import pickle
 import sys
 
-from clu import all
 from clu.constants import consts
-from clu.predicates import ispyname, negate
 from clu.typespace import types
-from clu.typology import iterlen
+from clu.predicates import (ispyname,
+                            negate,
+                            lowers)
+
 from clu.exporting import Exporter
 
 exporter = Exporter(path=__file__)
@@ -46,6 +48,7 @@ Results     = NamedTuple('Results',     ('total',
 class ModuleMap(collections.abc.Mapping,
                 collections.abc.Reversible,
                 clu.abstract.Cloneable,
+                clu.abstract.ReprWrapper,
                 metaclass=clu.abstract.Slotted):
     
     """ An adaptor class, wrapping a module and providing access to
@@ -61,10 +64,7 @@ class ModuleMap(collections.abc.Mapping,
             raise TypeError("valid module required")
         if not isinstance(module, (type(self), types.Module)):
             raise TypeError("module instance required")
-        if isinstance(module, type(self)):
-            self.module = getattr(module, 'module')
-        else:
-            self.module = module
+        self.module = getattr(module, 'module', module)
         self.reload()
     
     def __iter__(self):
@@ -86,7 +86,7 @@ class ModuleMap(collections.abc.Mapping,
         return out
     
     def __len__(self):
-        return iterlen(self.dir)
+        return len(self.dir)
     
     def keys(self):
         return clu.dicts.OrderedKeysView(self)
@@ -98,7 +98,7 @@ class ModuleMap(collections.abc.Mapping,
         return clu.dicts.OrderedItemsView(self)
     
     def reload(self):
-        self.dir = tuple(filter(notpyname, dir(self.module)))
+        self.dir = tuple(sorted(filter(notpyname, dir(self.module)), key=lowers))
         length = len(self.dir)
         if length < 1:
             raise ValueError("module instance must export one or more things")
@@ -113,6 +113,9 @@ class ModuleMap(collections.abc.Mapping,
         # N.B. since we can’t readily deep-clone a module,
         # all cloned instances are shallow:
         return type(self)(self)
+    
+    def inner_repr(self):
+        return repr(dict(self))
 
 @cache
 def compare_module_lookups_for_all_things(*modules, **options):
@@ -127,15 +130,24 @@ def compare_module_lookups_for_all_things(*modules, **options):
     """
     from clu.naming import nameof, moduleof
     
+    # N.B. This is not yet properly paramatrized,
+    # as it is using CLU’s exporter class, by fiat –
+    # it will need the “clu.application” stuff to
+    # be up and running to get around that, methinks
+    
+    basepath      = options.get('basepath',      consts.BASEPATH)
+    appname       = options.get('appname',       consts.APPNAME)
+    exporter_name = options.get('exporter_name', consts.EXPORTER_NAME)
+    
     idx = 0
     total = 0
     mismatch_count = 0
     mismatches = []
     results = []
     
-    clumodules = all.import_all_modules(consts.BASEPATH,
-                                        consts.APPNAME,
-                                        consts.EXPORTER_NAME)
+    clumodules = clu.all.import_all_modules(basepath,
+                                            appname,
+                                            exporter_name)
     assert clumodules
     
     modulenames = tuple(modules or Exporter.modulenames())
