@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 from __future__ import print_function, unicode_literals
 
@@ -20,7 +19,7 @@ FIELDS = ('major', 'minor', 'patch',
 
 # The `namedtuple` ancestor,
 # from which our VersionInfo struct inherits:
-VersionAncestor = NamedTuple('VersionAncestor', FIELDS, module=__name__) # type: ignore
+VersionAncestor = NamedTuple('VersionAncestor', FIELDS) # type: ignore
 
 # sets, for various comparisons and checks:
 fields = frozenset(FIELDS)
@@ -38,9 +37,9 @@ def intify(arg):
 def strify(arg):
     if arg is None:
         return None
-    if type(arg) in string_types:
+    if isinstance(arg, tuple(string_types)):
         return arg
-    if type(arg) in byte_types:
+    if isinstance(arg, tuple(byte_types)):
         return arg.decode('UTF-8') # type: ignore
     return str(arg)
 
@@ -51,7 +50,7 @@ def dictify(arg):
         return arg._asdict()
     if hasattr(arg, 'to_dict'):
         return arg.to_dict()
-    if type(arg) in dict_types:
+    if isinstance(arg, tuple(dict_types)):
         return arg
     return dict(arg)
 
@@ -143,8 +142,8 @@ class VersionInfo(VersionAncestor):
         return out
     
     def to_dict(self):
-        """ Really an OrderedDict but who’s counting? """
-        out = OrderedDict() # type: OrderedDict
+        """ Returns what you think it returns """
+        out = {} # type: dict
         for field in FIELDS:
             if getattr(self, field, None) is not None:
                 out[field] = getattr(self, field)
